bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 3. Aventiure
___________________________________________________ #### Aventivre wie sivrit #### ze wormze chome
###### 44 | ### Den herren mveten selten | deheiniv hercenleit ### er horte sagn maere | wi ein scoeniv meit ### waere in bvrgonden | ce wunsche wolgetan ### von der er sit vil vrevden | vnt ovch arbeit gewan
###### 45 | ### div ir vnmazen scoene | was vil witen chvnt ### vnt ir hoh gemvete | zvo der selbn stvnt ### an der ivnchfrovwen | so manech helt ervant ### ez ladete vil der geste | in daz gvnthers lant
###### 46 | ### swaz man der werbenden | nah ir minne sach ### chrimhilt in ir sinne | ir selber nie veriach ### daz si deheinen wolde | ce eime trvote han ### er was ir noch vil vremde | dem si wart sider vndertan
###### 47 | ### do gedaht vf hohe minne | daz siglinde kint ### ez was ir aller werben | wider in ein wint ### er mohte wol verdienen | scoener frovwen lip ### sit wart div edele chrimhilt | des chvenen sivrides wip
###### 48 | ### im rieten sine mage | vnt genvoge sine man ### sit er vf staete minne | wolde tragen wan ### daz er dan eine wurbe | div im mohte zemen ### do sprach der chvene sivrit | so wil ich chiemhilden nemen
###### 49 | ### dif scoenen ivnchfrovwen | von bvrgonden lant ### dvrch ir vnmazen scoene | daz ist mir wol bechant ### nie keiser wart so riche | der wolde haben wip ### im zaeme wol ce minnen | der richen chvneginne lip
###### 50 | ### disiv selbn maere | gehorte sigmvnt ### ez reiten sine livte | davon wart im chvnt ### der wille sines chindes | des was im harte leit ### daz er werbn wolde | di vil herlichen meit
###### 51 | ### ez gevriesc ovch siglint | des edelen kvneges wip ### si hete groze sorge | vm ir chindes lip ### wan si wol erchande | gvnthern vnt sine man ### den gewerp man dem degene | sere leiden began
###### 52 | ### do sprach der chvene sivrit | vil lieber vater min ### an edeler frovwen minne | wold ich immer sin ### ih en wurbe dar min herce | vil groze liebe hat ### swaz iemn reden chvnde | des ist decheiner slahte rat
###### 53 | ### vnt wildv niht erwinden | sprach der chvnech do ### so bin ich dins willen | waerlichen vro ### vnt wil dirz helfen enden | so ich allerbeste chan ### doch hat der chvnech gvnther | vil manegen hohferten man
###### 54 | ### ob ez ander niemn waere | wan hagene der degn ### der chan mit vbermvete | der hohverte pflegn ### daz ich des sere fverhte | ez mvg vns werden leit ### ob wir werbn welln | di vil herlichen meit
###### 55 | ### waz mag vns daz gewerren | sprach do sivrit ### swaz ih friwentliche | niht ab in erbit ### daz mach svs erwerbn | mit ellen da min hant ### ich truowe an in ertwingen | beide livte vnd lant
###### 56 | ### do sprach der fvrste sigmvnt | din rede div ist mir leit ### wan wurden disiv maere | ce rine geseit ### dv ne dorftest nimmer | geriten in daz lant ### gvnther vnt gernot | di sint mir lange bechant
###### 57 | ### mit gewalte niemn | erwerben mach di magt ### so sprach der kvnec sigmvnt | daz ist mir wol gesagt ### wilt aber dv mit rechen | riten in daz lant ### ob wir iht habn vriwende | di werdent sciere besant
###### 58 | ### des en ist mir niht ce mvote | sprach abr sivrit ### daz mir svlen rechen | ce rine volgen mit ### dvrh deheine hervart | daz waere mir vil leit ### damit ich solde ertwingen | di vil waetlichn meit
###### 59 | ### si mach wol svs erwerben | da min eines hant ### ich wil selbe zwelfte | in gvnthers lant ### dar svlt ir mir helfen | vater sigmvnt ### do gap man sinen degenen | ze chleidern gra vnd bvnt
###### 60 | ### do vernam ovch disiv maere | sin mvoter siglint ### si begvnde trvoren | vm ir liebez chint ### daz vorhte si verliesen | von gvnthers man ### div edele chvneginne | vil sere weinen began
###### 61 | ### sivrit der herre | gie da er si sach ### wider sine mvoter | er gvetliche sprach ### frovwe ir svlt niht weinen | dvrh den willen min ### ia wil ich an sorge | vor allen wiganden sin
###### 62 | ### vnd helfet mir der reise | in bvrgonden lant ### daz ich vnt mine rechen | habn soelch gewant ### daz also stolce helde | mit eren mvgen tragn ### des wil ich iv genade | mit triwen waerlichen sagn
###### 63 | ### sit dv niht wil erwinden | sprach frov siglint ### so hilf ich dir der reise | min einigez chint ### mit der besten waete | di riter ie getrvoch ### dir vnt dinen gesellen | ir svlt ir fveren genvoch
###### 64 | ### do neich der kvneginne | sivrit der ivnge man ### er sprach ih wil cer verte | niemn mer han ### niwan zwelf rechen | den sol man prveven wat ### ich wil daz sehen gerne | wi ez vm chrimhilde stat
###### 65 | ### do sazen scoene frovwen | naht vnd tach ### daz lvcel ir deheiniv | ruowe gepflach ### vnce man geworhte | di sivrids wat ### er wolde siner reise | habn deheiner slahte rat
###### 66 | ### sin vater hiez im cieren | sin riterlich gewant ### damit er wolde rvemen | daz sigmvnds lant ### vnt ir vil liehten brvenne | di wurden ovch bereit ### vnt ir vesten helme | ir schilde scoen vnde breit
###### 67 | ### do nahet in ir reise | cen bvrgonden dan ### vm si begvnde sorgen | wib vnde man ### ob si immer chomn solden | heim wider in daz lant ### di helde in hiezen sovmen | beide wafen vnt gewant
###### 68 | ### ir ross div waren scoene | ir gereite goldes rot ### lebt iemn vbermveter | des en was niht not ### denne waere sivrit | vnt di sine man ### vrlovbes er do gerte | zvo den bvrgonden dan
###### 69 | ### in werten trvrechlichen | der chvnech vnt sin wip ### er troste minnechlichen | do ir beider lip ### er sprach ir svlt niht weinen | dvrch den willen min ### immer ane sorge | svlt ir mines libes sin
###### 70 | ### ez was leit den rechen | ez weinte ovch manech meit ### ich waen in het ir herce | rehte daz geseit ### daz in so vil der friwende | davon gelaege tot ### von scvlden si do chlageten | des gie in waerliche not
###### 71 | ### an dem sibenden morgen | ce wormez vf den sant ### riten di vil chvenen | allez ir gewant ### was von rotem golde | ir gereite wolgetan ### ir ross in giengen ebene | des chvenen sivrids man
###### 72 | ### ir schilde waren niwe | lieht vnde breit ### vnt vil scoen ir helme | da ce hove reit ### sivrit der vil chvene | in gvnthers lant ### man gesach an helden | nie so herlich gewant
###### 73 | ### div ort ir swerten giengen | nider vf den sporn ### ez fvorten scaerpfe gern | di riter vzerchorn ### sivrit der fvort ir einen | wol zweier spannen breit ### der zvo sinen ecken | vil harte vreislichen sneit
###### 74 | ### die goltvarwen zovme | fvortens an der hant ### sidiniv fvrbvege | svs chomens in daz lant ### daz volch si allenthalbn | chapfen an began ### do liefen in engegene | vil der gvnthers man
###### 75 | ### die hohgemveten rechen | riter vnd chneht ### di giengen zvo den herrn | daz was michl reht ### vnt enpfiengen dise geste | in ir herrn lant ### vnt namen in di moere | mit den schilden von der hant
###### 76 | ### div ross si wolden dannen | ziehen an gemach ### sivrit der vil chvene | wi snelle er do sprach ### lat vns sten di moere | mir vnt minen man ### wir wellen sciere hinnen | des ich vil gvoten willen han
###### 77 | ### swem sin chvnt div maere | der sol mich niht verdagn ### wa ich den kvnec vinde | daz sol man mir sagn ### gvnthern den vil richen | vz bvrgonden lant ### do sagt ez im ir einer | dem ez rehte was bechant
###### 78 | ### welt ir den herrn vinden | daz mach vil wol gescehn ### in ienem sale witen | da han ich in gesehn ### bi den sinen helden | da svlt ir hine gan ### da mvgt ir bi im vinden | vil manegen herlichen man
###### 79 | ### nv waren dem kvnge | div maere geseit ### daz da chomen waeren | riter vil gemeit ### di fvortn wizze brvenne | vnt herlich gewant ### sin erchande niemn | in der bvrgonden lant
###### 80 | ### den kvnech des hete wunder | von wannen choemn dar ### di herlichen rechen | in wate lieht gevar ### vnt mit so gvoten scilden | niwe vnd breit ### daz im daz sagte niemn | daz was gvnthere leit
###### 81 | ### des antwurt dem kvnege | von mecen oertwin ### rich vnde chvene | moht er wol sin ### sit wir ir niht erchennen | nv svlt ir heizen gan ### nach minem oeheim hagenen | den svlt ir si sehen lan
###### 82 | ### dem sint chvnt div riche | vnt ovch div vremden lant ### sint im di herrn chvende | daz tvot er vns bechant ### der chvnech bat in bringen | vnt di sinen man ### man sach in herliche | mit rechen hinz hove gan
###### 83 | ### waz sin der kvnech wolde | des vragte hagene ### ez sint in mime hvse | vnchvnde degene ### di niemn hie bechennet | habt ir si ie gesehn ### des svlt ir mir her hagene | der rehten warheite iehn
###### 84 | ### daz tvon ich sprach hagne | ceinem venster er da gie ### sin ovge er do wenchen | zvo den gesten lie ### wol behagte im ir geverte | vnt ovch ir gewant ### si waren im vil vremde | in der bvrgonden lant
###### 85 | ### er sprach von swannen choemn | di rechen an den rin ### ez moehtn selbe fversten | oder fverstn boten sin ### ir ross div waeren scoene | ir chleider harte gvot ### von swannen daz si fveren | si waeren hohgemvot
###### 86 | ### also sprach do hagne | ich wil des wol veriehn ### swi ich sivriden | nimer hab gesehn ### so wil ich wol gelovben | swi ez darvmbe stat ### daz ez si der reche | der dort so herlichen gat
###### 87 | ### er bringet niwe maere | her in dize lant ### di chvenen nibelvnge | slvoch des heldes hant ### schilbvnch vnt nibelvngen | div richen chvneges kint ### er frvmte starchiv wunder | mit siner grozen chrefte sint
###### 88 | ### da der helt aleine | an alle helfe reit ### er vant vor eime berge | daz ist mir wol geseit ### bi nibelvnges horde | vil manegen chvenen man ### di waren im e vremde | vnz er ir chvnde da gewan
###### 89 | ### hort der nibelvnges | der was gar getragn ### vz eime holem berge | nv hoeret wunder sagn ### wi in wolden teilen | der nibelvnge man ### daz sach der degen sivrit | den helt ez wunderen began
###### 90 | ### er chom zvo zin so nahen | daz er di helde sach ### vnt ovch in di degene | ir einer drvnder sprach ### hie chvmt der starche sivrit | der helt von niderlant ### vil seltsaeniv maere | er an den niblvngen vant
###### 91 | ### den rechen wol enpfiengen | scilbvnch vnt nibelvnch ### mit gemeinem rate | di edeln fvrsten ivnch ### den scaz in baten teilen | den waetlichen man ### vnt gerten des mit vlize | der herre lobn inz began
###### 92 | ### er sach so vil gesteines | so wir hoeren sagn ### hvndert chanzwaegene | ez moehten niht getragn ### noch me des roten goldes | von nibelvnge lant ### daz sold in allez teilen | des chvenen sivrides hant
###### 93 | ### do gaben si im ce miete | daz nibelvnges swert ### si waren mit dem dienste | vil vbele gewert ### den in da leisten solde | sivrit der helt gvot ### ern chvndez niht verenden | si waren zornech gemvot
###### 94 | ### si heten da ir frivnde | zwelf chvene man ### daz starche risen waren | waz chvndez si vervan ### di slvoch sit mit zorne | div sivrids hant ### vnt rechen siben hvndert | twang er von nibelvnge lant
###### 95 | ### mit dem gvotem swerte | daz hiez balmvnch ### dvrch di starchen vorhte | vil manech reche ivnch ### di si cem swerte heten | vnt an den chvenen man ### daz lant zvo den bvergen | si im taten vndertan
###### 96 | ### darzvo di richen chvnge | di slvog er bede tot ### er chom von albriche | sit in groze not ### der wande sine herrn | rechen da cehant ### vnz er di grozen sterche | sit an sivride vant
###### 97 | ### do ne chvnd im niht gestriten | daz starche getwerch ### alsam di lewen wilde | si liefen an den perch ### da er di tarenkappen | sit albriche an gewan ### do was der hordes herre | sivrit der vreisliche man
###### 98 | ### di da torsten vehten | di lagen alle erslagn ### den scaz den hiez er balde | fveren vnde tragn ### da in davor da namen | di nibelvnge man ### albrich der vil starche | do di kamern gewan
###### 99 | ### er mvos im sweren eide | er diente im so sin chneht ### aller hande dinge | was er im gereht ### so sprach von tronege hagene | daz hat er getan ### also grozer chrefte | nie mer reche gewan
###### 100 | ### noch weiz ich an im mere | daz mir ist bechant ### einen lintrachen den | slvoch des heldes hant ### er badet sich in dem blvote | sin hvt wart hvrnin ### des snidet in chein wafen | daz ist diche worden scin
###### 101 | ### wir svln den herrn | enpfahen deste baz ### daz wir iht verdienen | des ivngen rechen haz ### sin lip der ist so chvene | man sol in holden han ### er hat mit siner chrefte | so menegiv wunder getan
###### 102 | ### do sprach der kvnech riche | dv maht wol habn war ### nv sich wi degenliche | er stet in strites var ### er vnt di sinen degene | der vil chvene man ### wir svlen im engegene | hin nider zvo dem rechen gan
###### 103 | ### daz mugt ir sprach do hagene | wol mit ern tvon ### er ist von edelem chvnne | eines richen kvnegs svn ### er stet in der gebaere | mich dvnchet wizze christ ### ez en sin niht chleiniv maere | darvmb er her geriten ist
###### 104 | ### do sprach der kvnech des landes | nv si vns willechomn ### er ist edel vnd chvene | daz han ich wol vernomn ### des sol ovch er geniezen | in bvrgonden lant ### do gie der herre gvnther | da er sivriden vant
###### 105 | ### der wirt vnt sine rechen | enpfiengen so den gast ### daz in an ir zvehten | vil wenech iht gebrast ### des begvnd in nigen | der waetliche man ### daz si in heten grvezen | so rehte scone getan
###### 106 | ### mich wundert dirre maere | sprach der kvnech cehant ### von wannen ir edel sivrit | sit chomn in dizze lant ### oder waz ir wellent werben | ze wormez an den rin ### do sprach der gast cem kvnege | daz sol ivch vnverdaget sin
###### 107 | ### mir wart gesaget maere | in mins vater lant ### daz hie bi iv waeren | daz het ich gern erchant ### di chvensten rechen | des han ich vil vernomn ### di ie chvnech gewunne | darvmbe bin ich her bechomn
###### 108 | ### ovch hoere ich iv selben | der degenheite iehn ### daz man kvnec deheinen | chvener hab gesehn ### des redent vil di livte | vber elliv disiv lant ### nv wil ich niht erwinden | vnz ez mir werde bechant
###### 109 | ### ich bin ovch ein reche | vnt solde chrone tragn ### ich wil daz gerne fvegen | daz si von mir sagn ### daz ich hab von rehte | livte vnde lant ### darvmbe sol min ere | vnt ovch min hovbet wesen pfant
###### 110 | ### nv ir sit so chvene | als mir ist geseit ### so ne rvoch ich ist daz iemn | lieb oder leit ### ich wil an iv ertwingen | swaz ir mvget han ### lant vnde bvrge | daz sol mir werden vndertan
###### 111 | ### den kvnec hete wunder | vnt sine man alsam ### vm disiv maere | di er hie vernam ### daz er des hete willen | er naeme im siniv lant ### daz horten sine degene | do wart in zvernen bechant
###### 112 | ### wie het ich daz verdienet | sprach gvnther der degn ### des min vater lange | mit eren hat gepflegn ### daz wir daz solden vliesen | von iemannes chraft ### wir liezen vbele schinen | daz wir ovch pflegn riterschaft
###### 113 | ### ine wil es niht erwinden | sprach aber der chvene man ### ez en mvge von dinen ellen | din lant den fride han ### ich wil es alles walden | vnd ovch div erbe min ### erwirbest dvz mit sterche | div svelen dir vndertaenech sin
###### 114 | ### din erbe vnt ovch daz mine | svlen geliche lign ### sweder vnser einer | am andern mach gesign ### dem sol ez allez dienen | di livte vnd ovch div lant ### daz widerredete hagene | vnt gernot cehant
###### 115 | ### wir han des niht gedingen | sprach do gernot ### daz wir iht lande ertwingen | daz iemn drvmbe tot ### gelige vor heldes handen | wir habn richiv lant ### div dienent vns von rehte | ze niemn sint si baz bewant
###### 116 | ### mit grimmigem mvote | da stvonden friwende sin ### do was ovch darvnder | von mecen oertwin ### der sprach disiv svone div | ist mir harte leit ### iv hat der starche sivrit | vnverdient widerseit
###### 117 | ### ob ir vnt iwer brvoder | hetet niht di wer ### vnd ob er danne fvorte | ein gancez kvneges her ### ih trvote wol erstriten | daz der chvene man ### diz starchez vbermveten | von waren schvlden mvese lan
###### 118 | ### daz zvrnde harte sere | der helt von niderlant ### er sprach sich sol vermezzen | niht wider mich din hant ### ich bin ein kvnec riche | so bistv kvneges man ### ia ne dorften mich din zwelve | mit strite nimmer bestan
###### 119 | ### nach swerten rief do sere | von mecen oertwin ### er mohte hagenen swestersun | von tronege vil wol sin ### daz der so lange dagete | daz was dem kvnege leit ### do vnderstvond ez gernot | der riter chven vnt gemeit
###### 120 | ### er sprach ce oertwine | lat iwer zvrnen stan ### vns en hat der herre sivrit | solhes niht getan ### wir en mvgenz noch wol sceiden | mit zvehten deist min rat ### vnt habn in ce friwende | daz vns noch loblicher stat
###### 121 | ### do sprach der starche hagne | vns mach wol wesen leit ### allen dinen degenen | daz er ie gereit ### dvrch striten her ce rine | | er soltez habn lan ### im heten mine herren | soelher leide niht getan
###### 122 | ### des antwurte sivrit der chreftige man ### mvet ivch daz her hagene | daz ich gesprochen han ### so sol ich lazen chiesen | daz die hende min ### wellent vil gewaltech | hie cen bvrgonden sin
###### 123 | ### daz sol ich eine wenden | sprach aber gernot ### allen sinen degenen | reden er verbot ### iht mit vbermvete | des im waere leit ### do gedahte ovch sivrit | an di herlichen meit
###### 124 | ### vie zaeme vns mit iv striten | sprach aber gernot ### swaz helde nv darvnder | mvese ligen tot ### wir hetens lvcel ere | vnt ir vil chleinen frvm ### des antwurte im do sivrit | des kvnech sigmvndes svn
###### 125 | ### warvmbe bitet hagne | vnt ovch oertwin ### daz er niht gaht striten | mit den friwenden sin ### der er hie so manegn | cen bvrgonden hat ### si mvosen rede vermiden | daz was gernotes rat
###### 126 | ### er svlt vns wesen willechomn | so sprach daz voten kint ### mit iwern gesellen | di mit iv chomn sint ### wir svlen iv gerne dienen | ich vnt di mage min ### do hiez man den gesten | scenchen den gvnthers win
###### 127 | ### do sprach der wirt des landes | allez daz wir han ### gervochet irs nach eren | daz si iv vndertan ### vnt si mit iv geteilet blib vnde gvot ### do wart der herre sivrit | ein lvcel sanfter gemvot
###### 128 | ### do hiez man in gehalten | allez ir gewant ### man svochte herberge | di besten di man vant ### sivrids chnehten | man scvof in gvot gemach ### den gast man sit vil gerne | da cen bvrgonden sach
###### 129 | ### man bot im michel ere | darnach ce manegn tagn ### tvsent stvnden mere | dann ich iv chan gesagn ### daz het versolt sin ellen | ir svlt gelovben daz ### in sach vil lvcel iemen | der im waere gehaz
###### 130 | ### sich vlizen chvrzwile | di kvnege vnt ovch ir man ### so was er ie der beste | swes man da began ### des en chvnd im gevolgen niemen | so michel was sin chraft ### so si den stein wurfn | oder schvzen den scaft
###### 131 | ### swa so bi den frovwen | dvrch ir hofscheit ### chvrcewile pflagen | di riter vil gemeit ### da sah man ie vil gerne | den helt von niderlant ### er het vf hohe minne | sine sinne gewant
###### 132 | ### swes man ie begvnde | des was sin lip bereit ### er trvog in sime sinne | ein minnechliche meit ### vnt ovch in ein div frovwe | di er noh nie gesach ### div im in heinliche | vil diche gvetlichen sprach
###### 133 | ### swenne vf dem hove wolden | spilen da div kint ### riter vnd chnehte | daz sach vil diche sint ### chrimhilt dvrch div venster | div kvneginne her ### deheiner chvrzwile | bedorftes in den citen mer
###### 134 | ### wesser daz in saehe | di er in hercen trvoch ### da het er chvrzewile | immer von genvoch ### saehen sie siniv ovgen | ich wil wol wizen daz ### daz im in dirre werlde | chvnde nimmer werden baz
###### 135 | ### swenner er bi den helden | vf dem hove stvont ### also noch di livte | dvrch chvrcewile tvont ### so stvont so minnechliche | daz siglinde kint ### daz in dvrch hercenliebe | trvote manech frovwe sint
###### 136 | ### er gedaht ovch manege cite | wi sol daz gescehen ### daz ich di maget edele | mit ovgen mvge sehen ### di ich von hercen minne | vnt lange han getan ### div ist mir noch vil vremde | des mvoz ich trvorich stan
###### 137 | ### so ie di kvnege riche | riten in ir lant ### so mvosen ovch di rechen | mit in al cehant ### damite mvos ovch sivrit | daz was der frovn leit ### er leit ovch von ir minne | diche michel arbeit
###### 138 | ### svss wont er bi den herrn | daz ist alwar ### in gvnthers lande | vollechlich ein iar ### daz er di minnechlichen | di cite nien gesach ### davon im sit vil liebe | vnt ovch vil leide gescach

<<< Übersicht <<< vorige Seite nächste Seite >>>